==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_fields/POSITIONPARENT_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour POSITIONPARENT_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="POSITIONPARENT_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}POSITIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTROLLUP" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOANEDTODEPARTMENTID" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "POSITIONPARENT_Type", propOrder = {
    "positionid",
    "type",
    "costrollup",
    "departmentid",
    "loanedtodepartmentid"
})
public class POSITIONPARENT_Type {

    @XmlElement(name = "POSITIONID", required = true)
    protected EQUIPMENTID_Type positionid;
    @XmlElement(name = "TYPE")
    protected TYPE_Type type;
    @XmlElement(name = "COSTROLLUP")
    protected String costrollup;
    @XmlElement(name = "DEPARTMENTID")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "LOANEDTODEPARTMENTID")
    protected DEPARTMENTID_Type loanedtodepartmentid;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété positionid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getPOSITIONID() {
        return positionid;
    }

    /**
     * Définit la valeur de la propriété positionid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setPOSITIONID(EQUIPMENTID_Type value) {
        this.positionid = value;
    }

    /**
     * Obtient la valeur de la propriété type.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Définit la valeur de la propriété type.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Obtient la valeur de la propriété costrollup.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOSTROLLUP() {
        return costrollup;
    }

    /**
     * Définit la valeur de la propriété costrollup.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOSTROLLUP(String value) {
        this.costrollup = value;
    }

    /**
     * Obtient la valeur de la propriété departmentid.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Définit la valeur de la propriété departmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Obtient la valeur de la propriété loanedtodepartmentid.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getLOANEDTODEPARTMENTID() {
        return loanedtodepartmentid;
    }

    /**
     * Définit la valeur de la propriété loanedtodepartmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setLOANEDTODEPARTMENTID(DEPARTMENTID_Type value) {
        this.loanedtodepartmentid = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/POSITIONPARENT_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for POSITIONPARENT_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="POSITIONPARENT_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}POSITIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COSTROLLUP" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOANEDTODEPARTMENTID" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "POSITIONPARENT_Type", propOrder = {
    "positionid",
    "type",
    "costrollup",
    "departmentid",
    "loanedtodepartmentid"
})
public class POSITIONPARENT_Type {

    @XmlElement(name = "POSITIONID", required = true)
    protected EQUIPMENTID_Type positionid;
    @XmlElement(name = "TYPE")
    protected TYPE_Type type;
    @XmlElement(name = "COSTROLLUP")
    protected String costrollup;
    @XmlElement(name = "DEPARTMENTID")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "LOANEDTODEPARTMENTID")
    protected DEPARTMENTID_Type loanedtodepartmentid;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the positionid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getPOSITIONID() {
        return positionid;
    }

    /**
     * Sets the value of the positionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setPOSITIONID(EQUIPMENTID_Type value) {
        this.positionid = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Gets the value of the costrollup property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOSTROLLUP() {
        return costrollup;
    }

    /**
     * Sets the value of the costrollup property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOSTROLLUP(String value) {
        this.costrollup = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the loanedtodepartmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getLOANEDTODEPARTMENTID() {
        return loanedtodepartmentid;
    }

    /**
     * Sets the value of the loanedtodepartmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setLOANEDTODEPARTMENTID(DEPARTMENTID_Type value) {
        this.loanedtodepartmentid = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
